export interface IHeadingStyle {
    fontFamily: string;
    fontSize: number;
    letterSpacing: number;
    lineHeight: number;
    textAlign: 'left' | 'center' | 'right' | 'undefined';
    textTransform: string;
    [key: string]: string | number;
}
export interface ITypography {
    fontFamily: string;
    h1: IHeadingStyle;
    h2: IHeadingStyle;
    h3: IHeadingStyle;
    h4: IHeadingStyle;
    h5: IHeadingStyle;
    h6: IHeadingStyle;
    p1: IHeadingStyle;
    p2: IHeadingStyle;
    p3: IHeadingStyle;
    p4: IHeadingStyle;
    p5: IHeadingStyle;
    p6: IHeadingStyle;
    [key: string]: 'left' | 'center' | 'right' | 'undefined' | string | IHeadingStyle;
}
export interface IColors {
    [key: string]: string;
}
export interface IMisc {
    [key: string]: unknown;
}
export interface ISpacing {
    xsmall: number;
    small: number;
    medium: number;
    default: number;
    large: number;
    xlarge: number;
    huge: number;
    [key: string]: number;
}
export interface IBreakpoints {
    mobileS: string;
    mobileM: string;
    mobileL: string;
    tablet: string;
    laptop: string;
    laptopL: string;
    desktop: string;
    [key: string]: string;
}
export interface IRadius {
    default: number;
    double: number;
    half: number;
    full: number;
    [key: string]: number;
}
export interface IShadow {
    default: string;
    medium: string;
    [key: string]: string;
}
export interface IZindex {
    dropdown: number;
    pageFooter: number;
    modal: number;
    [key: string]: string | number;
}
export interface IRNTheme {
    breakpoints: IBreakpoints;
    colors: IColors;
    misc: IMisc;
    radius: IRadius;
    shadow: IShadow;
    spacing: ISpacing;
    typography: ITypography;
    zIndex: IZindex;
}
export declare const theme: IRNTheme;
